<?php

/*
Plugin Name: CookieHint WP
Plugin URI: https://www.redim.de/downloads/wordpress/cookiehint-wp
Description: Plugin zur Erstellung eines Cookie Consent Banners auf der Website.
Version: 1.0.0
Author: reDim GmbH
Author URI: https://www.redim.de/
Requires at least: 5.2
Requires PHP: 7.2
License: GPL v2 or later
License URI: https://www.gnu.org/licenses/gpl-2.0.html
*/	

/*
CookieHint is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 2 of the License, or
any later version.

CookieHint is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with CookieHint. If not, see https://www.gnu.org/licenses/gpl-2.0.html.
*/
		
	
	if(!defined('ABSPATH')){
		die('-1');
	}
	
	#Includes & requires
	include(plugin_dir_path(__FILE__).'backend-functions.php');
	include(plugin_dir_path(__FILE__).'shortcode-functions.php');
	include(plugin_dir_path(__FILE__).'update.php');
	include(plugin_dir_path(__FILE__).'admin.php');
	require_once(plugin_dir_path(__FILE__).'classes/cookiehint.php');
	
	#Actions & Hooks
	#Main functions
	add_action('plugins_loaded', 'ckrd_initial_action');
	#Admin menu
	add_action('admin_menu', 'ckrd_admin_menu_nav');
	#Frontend CSS & JS
	add_action('wp_enqueue_scripts', 'ckrd_enqueue_frontend_files');
	#Backend CSS & JS
	add_action('admin_enqueue_scripts', 'ckrd_enqueue_admin_files');
	#Language file load
	add_action('plugins_loaded', 'ckrd_load_lang_files');
	#Functions after installation
	register_activation_hook(__FILE__, 'ckrd_installer');
	
	
	function ckrd_installer(){
		
		include('installer.php');
	}
	
	function ckrd_enqueue_frontend_files(){
		
		$rd            = new CKRD_Cookiehint();
		$css           = $rd->cookiehint_add_css();
		$tmp_name_file = (plugins_url($css, __FILE__));
		wp_enqueue_style('default-cookiehint', plugins_url('assets/css/default.css', __FILE__));
		wp_enqueue_style('cookiehint-style', $tmp_name_file);
		
		wp_enqueue_script('jquery');
		wp_register_script('script-js', plugins_url('assets/js/script.js', __FILE__), false, '1.0.0');
		wp_enqueue_script('script-js');
	}
	
	function ckrd_load_lang_files(){
		
		$path   = dirname(plugin_basename(__FILE__)).'/lang';
		$result = load_plugin_textdomain(dirname(plugin_basename(__FILE__)), false, $path);
		if(!$result){
			get_locale();
			$lang_page = get_locale();
			$lang_page = substr($lang_page, 0, 2);
			
			#### TO DO ####
			# Languages with different regions, simplified to only use one translation
			# Portuguese(pt) and Russian(ru) are still missing
			#### TO DO ####
			
			switch($lang_page){
				case "en":
					$mofile = "cookiehint-en_GB.mo";
					load_textdomain(dirname(plugin_basename(__FILE__)), dirname(__FILE__).'/lang/'.$mofile);
					break;
				case "es":
					$mofile = "cookiehint-es_ES.mo";
					load_textdomain(dirname(plugin_basename(__FILE__)), dirname(__FILE__).'/lang/'.$mofile);
					break;
				case "de":
					$mofile = "cookiehint-de_DE.mo";
					load_textdomain(dirname(plugin_basename(__FILE__)), dirname(__FILE__).'/lang/'.$mofile);
					break;
				case "fr":
					$mofile = "cookiehint-fr_FR.mo";
					load_textdomain(dirname(plugin_basename(__FILE__)), dirname(__FILE__).'/lang/'.$mofile);
					break;
				case "nl":
					$mofile = "cookiehint-nl_NL.mo";
					load_textdomain(dirname(plugin_basename(__FILE__)), dirname(__FILE__).'/lang/'.$mofile);
					break;
				default:
					# Default language if not exits the regional
					$mofile = "cookiehint-en_GB.mo";
					load_textdomain(dirname(plugin_basename(__FILE__)), dirname(__FILE__).'/lang/'.$mofile);
			}
		}
	}
	
	
	function ckrd_initial_action(){
		
		$rd = new CKRD_Cookiehint();
		
		if(is_user_logged_in() || (is_admin())){
			if($rd->getVAR("rCH") == 4){
				if (isset($_POST['action']) && !empty($_POST['action']) && $_POST['action'] == 'cookie_action') {
					unset($_POST['action']);
				}else{
					$rd->cookiehint_paramscheck(4);
				}
			}else{
				return;
			}
			
			
		}
		
		$rd->getVAR("rCH");
		$test_modus = 0;
		session_start();
		
		if((isset($_COOKIE['cookiehint']) && !empty($_COOKIE['cookiehint'])) || (isset($_SESSION["cookiehintsession"]) && !empty($_SESSION["cookiehintsession"]))){
			
			if($rd->getVAR("rCH") == 3){
				$rd->cookiehint_paramscheck(3);
			}else if(isset($_SESSION["cookiehintsession"]) && $_SESSION["cookiehintsession"] == 1){
				$rd->cookieblocker_modus();
			}else{
			}
		}else if (isset($_POST['action']) && !empty($_POST['action']) && $_POST['action'] == 'cookie_action') {
			if (isset($_POST['cookie_accept'])) {
				$rd->cookiehint_paramscheck(2);
			} else if (isset($_POST['cookie_decline'])) {
				$rd->cookiehint_paramscheck(1);
			}
		}else{
			$rd->cookieblocker_modus();
			cookiehint_popup_activation();
		}
	}
	
	
	function cookiehint_cookiecheck($v){
		print_r($v);
	}
	
	
	function cookiehint_popup_activation(){
		
		add_action('wp_footer', 'cookiehint_popup');
	}
	
	
	function cookiehint_popup(){
		
		$rd = new CKRD_Cookiehint();
		$current_uri = $rd->current_uri_wp();
		
		
		$linknotok         = add_query_arg('rCH', '1', $current_uri);
		$linkok            = add_query_arg('rCH', '2', $current_uri);
		$linkremove        = add_query_arg('rCH', '3', $current_uri);
		$linkimprint       = $rd->linkimprint();
		$linkprivacypolicy = $rd->linkprivacypolicy();
		$position          = $rd->position_popup();
		$refusal           = $rd->refusal_btn();
		$notxt             = "Are you sure?";
		
		
		add_filter( 'wp_robots', 'wp_robots_no_robots_cookiehint' );
		
		$php_html_code_file = $rd->request_files_template();
		include plugin_dir_path(__FILE__).$php_html_code_file;
	}
	
	#### TO DO ####
	function wp_robots_no_robots_cookiehint( array $robots ) {
		$robots['noindex'] = true;
	 
		return $robots;
	}